@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use POE::Component::IRC::Plugin qw(:ALL);
 
-our $VERSION = '1.1';
+my $VERSION = '1.1';
 
 sub new {
     my $package = shift;
@@ -87,20 +87,19 @@ sub S_433 {
     # this is the nickname which we failed to get...
     my $offending = ${ $_[2] }->[0];
     
-    # abort reclaiming, we already have a nick we can use...
+    # only reclaim if we don't have a nick we can use...
     #...and it's not a startup routine where ->nick_name cannot
     #...be used (and needs to be reclaimed)
-    return PCI_EAT_NONE
-        if $self->{_did_start} and $irc->nick_name() ne $offending;
-    
-    # we will store the nick with the underscore in ->{_claims}...
-    #...so in sub U_nick{} we would know which ones were caused...
-    #...by NickReclaim and which ones need to change the "real" nick
-    $offending .= '_';
-    $self->{_claims}{ $offending } = 1;
-    
-    # we will kindly ask the server to give us the nick with an underscore...
-    $irc->yield( nick => $offending );
+    if (!$self->{_did_start} || $irc->nick_name() eq $offending) {
+        # we will store the nick with the underscore in ->{_claims}...
+        #...so in sub U_nick{} we would know which ones were caused...
+        #...by NickReclaim and which ones need to change the "real" nick
+        $offending .= '_';
+        $self->{_claims}{ $offending } = 1;
+        
+        # we will kindly ask the server to give us the nick with an underscore...
+        $irc->yield( nick => $offending );
+    }
 
     # cancel old alarm, we won't need it anymore, considering we are going...
     #...to post a new one.
