@@ -2,12 +2,13 @@
 package POE::Component::IRC::Plugin::Whois;
 
 # Standard stuff to catch errors
+use strict;                          # Make sure we can't mess up
+use warnings;                            # Enable warnings to catch errors
 use POE;
-use strict qw(subs vars refs);                          # Make sure we can't mess up
-use warnings FATAL => 'all';                            # Enable warnings to catch errors
+use vars qw($VERSION);
 
 # Initialize our version
-our $VERSION = '0.02';
+$VERSION = '0.03';
 
 # Import the stuff from Plugin
 use POE::Component::IRC::Plugin qw( PCI_EAT_NONE );
@@ -190,6 +191,16 @@ POE::Component::IRC::Plugin::Whois is the reimplementation of the 'irc_whois' an
 L<POE::Component::IRC> as a plugin. It is used internally by L<POE::Component::IRC>
 so there is no need to use this plugin yourself.
 
+=head1 CONSTRUCTOR
+
+=over
+
+=item new
+
+No arguments required. Returns an POE::Component::IRC::Plugin::Whois object.
+
+=back
+
 =head1 AUTHOR
 
 Chris "BinGOs" Williams
